(*
sleon is a small toy that shuffles the letters of each word of a text,
preserving the first and the last letter.
The idea is that (at least in french) the text is still readable.

Copyright (C) 2004 Jean-Baptiste Rouquier
(search the web for "Jean-Baptiste Rouquier" if you want my email)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*)

open Tools

let input_file = ref stdin
let output_file = ref stdout

let speclist = []
and anonfun =
  let rec f = ref (
    fun file ->
      input_file := open_in file;
      f := (
        fun file ->
          output_file := open_out file;
          f := (
          fun string ->
            Printf.eprintf "warning, only input and output file are needed, \
                            argument %s is ignored.\n" string))) in
  fun string -> !f string
and usage_msg = (Printf.sprintf "usage: %s [input_file [output_file]]\n\
                                 defaults are standard input and output."
		   (Filename.basename Sys.executable_name))

let main () =
  let output = output_string !output_file in
  try while true do
    let line = input_line !input_file in
    let non_word, words = split_mots line in
    output non_word;
    let iterator (word, non_word) =
      shuffle_mot word;
      output word; output non_word in
    List.iter iterator words;
    Printf.fprintf !output_file "\n%!";
  done with End_of_file -> ();
(*   if !input_file <> stdin then *)
    close_in !input_file;
(*   if !output_file <> stdout then *)
    close_out !output_file

let main_cmd_line () =
  Arg.parse speclist anonfun usage_msg;
  main ()

let main_dialog () =
  let files = Sys.readdir (Sys.getcwd ()) in
  let check_suffix suff name = Filename.check_suffix name suff in
  let files = List.filter (check_suffix "txt") (Array.to_list files) in
  let continue = ref true in
  while !continue do
    let string =
      (match files with
         | [] ->
             Printf.printf "Tapez le nom du fichier a lire\n  (Ctrl+c pour quitter) : ";
(*              let file = *)
               read_line ()
(*              in *)
(*              if file = "q" then exit 0; *)
(*              file *)
         | default :: _ ->
             Printf.printf "Tapez le nom du fichier a lire\n  \
                            (Ctrl+c pour quitter, entree pour utiliser %s) : " default;
             match read_line () with
(*                | "q" -> exit 0 *)
               | "" -> default
               | file -> file
      ) in
    if Sys.file_exists string
    then (input_file := open_in string; continue := false)
    else let string_txt = string ^ ".txt" in
    ( if Sys.file_exists string_txt
      then (input_file := open_in string_txt; continue := false)
      else Printf.eprintf "le fichier %s ou %s n'exsite pas\n%!" string string_txt)
  done;
  let default = "sleon.txt" in
  Printf.printf "Tapez le nom du fichier resultat\n  \
                 (Ctrl+c pour quitter, entree pour utiliser %s,\n  \
                 attention ce fichier sera supprime s'il existe deja) : "
    default;
  output_file := open_out
    (match read_line () with
(*        | "q" -> exit 0 *)
       | "" -> default
       | file -> if Filename.check_suffix file "txt" then file else file ^ ".txt"
    );
  main ()

